@@ -8,7 +8,7 @@ package Object::Pad;
 use strict;
 use warnings;
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 use Carp;
 
@@ -414,7 +414,7 @@ See also
 
 =item *
 
-L<https://github.com/Perl-Toolchain-Gang/Module-Metadata/issues/3://github.com/Perl-Toolchain-Gang/Module-Metadata/issues/33>
+L<https://github.com/Perl-Toolchain-Gang/Module-Metadata/issues/33>
 
 =back
 
